import React, { Children, cloneElement, isValidElement, useState, ReactNode } from 'react';
import './Accordion.css';

export interface AccordionProps {
    children: ReactNode[]
    allowMultipleExpanded?: boolean,
    preExpanded?: number[],
    expandAll?: boolean
}

const Accordion = ({ children, allowMultipleExpanded, preExpanded, expandAll }: AccordionProps) => {
    const getInitialItemExpandStatusList = () => {
        let list: boolean[] = [];
        for (let index = 0; index < children.length; index++) {
            let flag = false;
            if (expandAll) flag = true;
            else if (preExpanded && Array.isArray(preExpanded)) flag = preExpanded.includes(index) ? true : false
            list.push(flag)
        }
        return list;
    }
    const [itemExpandStatusList, setItemExpandStatusList] = useState<boolean[]>(getInitialItemExpandStatusList());

    const handleItemExpandStatusListChange = (index: number, status: boolean) => {
        setItemExpandStatusList(itemExpandStatusList.map((x: boolean, i: number) => i === index ? status : allowMultipleExpanded ? x : false));
    }

    return (
        <div className='gj-accordion'>
            {Children.map(children, (child, index: number) => {
                if (!isValidElement(child)) return null;
                else return cloneElement(child, { isOpen: itemExpandStatusList[index], setIsOpen: handleItemExpandStatusListChange, itemIndex: index } as any);
            })
            }
        </div>
    );
}
export default Accordion;

