import React, { useRef, useState, Children, cloneElement, isValidElement, useEffect, ReactNode } from 'react';
import AccordionHeader from './AccordionHeader';
import AccordionBody from './AccordionBody';

export interface AccordionItemProps {
    children: ReactNode;
    isOpen?: boolean;
    setIsOpen?: (index: number, isOpen: boolean) => void;
    itemIndex?: number;
}

const AccordionItem = ({ children, isOpen, setIsOpen, itemIndex }: AccordionItemProps) => {

    const [maxHeight, setMaxHeight] = useState(0);

    const accordionBodyRef = useRef<HTMLInputElement>(null);

    useEffect(() => setMaxHeight(!isOpen ? 0 : accordionBodyRef?.current?.scrollHeight || 0), [isOpen]);

    const handleIconClick = (index: number) => {
        setIsOpen && setIsOpen(index, !isOpen);
    }

    return (
        <div className='gj-accordion-item'>
            {
                Children.map(children, child => {
                    if (!isValidElement(child)) return null;
                    else if (child.type === AccordionHeader) return cloneElement(child, { handleIconClick, isOpen, itemIndex } as any);
                    else if (child.type === AccordionBody) return cloneElement(child, { maxHeight, ref: accordionBodyRef } as any);
                    else return null;
                })
            }
        </div>
    );
}

export default AccordionItem;

